@@ -426,7 +426,7 @@ def compile_dataframe_for_all_datasets_on_metric(openmlids, metric):
     return df_results
 
 
-def get_all_curves_for_metric(metric="accuracy"):
+def get_all_curves(metric = "accuracy"):
     supported_metrics = ["accuracy", "logloss"]
     if not metric in supported_metrics:
         raise ValueError(f"Unsupported metric {metric}. Supported metrics are {supported_metrics}")
